<?php
/*
 * @package Recent Forum Topics
 * @version 2.0
 * @Author: Pipke(AdemaStudios)
 * @copyright Copyright (C) 2015, Pipke
 * @All rights reserved. 
 * @This SMF modification is subject to the BSD 2-Clause License
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 * HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON 
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

if (!defined('SMF'))
	die('Hacking attempt...');

// Do direct options on block
function rftblock()
{
	global $topic, $board, $smcFunc, $modSettings, $txt, $context;
	
	if (!isset($_REQUEST['area']))
		fatal_lang_error('no_access', false);
	
	//Build array from current action
		$rft_current_action = array($modSettings['rft_current_action']);
	//Build array hidden topics
		$rft_topics = !empty($modSettings['rft_hide_topics']) ? unserialize($modSettings['rft_hide_topics']) : array();
	
	
	if (isset($_REQUEST['area']) && ($_REQUEST['area'] == 'boost'))
	{
		// Just quit if there's no topic to boost.
		if (empty($topic))
			fatal_lang_error('not_a_topic', false);
		
		// Always do the permission check!
		if (!allowedTo('rft_permission_boost'))
		  fatal_error(sprintf($txt['rft_cannot_boost']), false);
		
		// Make sure that the correct session was passed?
		checkSession('get');
		
		if (in_array($topic, $rft_topics))
			fatal_error(sprintf($txt['rft_boost_is_hidden']), false);
			
		if (empty($modSettings['rft_boost_1']))
			updateSettings(array('rft_boost_1' => $topic));
		elseif (empty($modSettings['rft_boost_2']))
			updateSettings(array('rft_boost_2' => $topic));
		else
			fatal_error(sprintf($txt['rft_boost_full']), false);
		
		// Log this boost action - always a moderator thing.
		logAction('boosted', array('topic' => $topic, 'board' => $board));
		
		// Take them back to the boosted topic.
		redirectexit('topic=' . $topic . '.' . $_REQUEST['start'] . (WIRELESS ? ';moderate' : ''));
	}
	
	if (isset($_REQUEST['area']) && ($_REQUEST['area'] == 'release'))
	{
		// Just quit if there's no topic to boost.
		if (empty($topic))
			fatal_lang_error('not_a_topic', false);
		
		// Always do the permission check!
		if (!allowedTo('rft_permission_boost'))
		  fatal_error(sprintf($txt['rft_cannot_release']), false);
		
		// Make sure that the correct session was passed?
		checkSession('get');
		
		if ($topic == $modSettings['rft_boost_1'])
			updateSettings(array('rft_boost_1' => false));
		elseif ($topic == $modSettings['rft_boost_2'])
			updateSettings(array('rft_boost_2' => false));
		else
			fatal_error(sprintf($txt['rft_nomatch_release']), false);		
		
		// Log this boost action - always a moderator thing.
		logAction('released', array('topic' => $topic, 'board' => $board));
		
		// Take them back to the boosted topic.
		redirectexit('topic=' . $topic . '.' . $_REQUEST['start'] . (WIRELESS ? ';moderate' : ''));
	}
	
	if (isset($_REQUEST['area']) && ($_REQUEST['area'] == 'hide'))
	{
		// Just quit if there's no topic to boost.
		if (empty($topic))
			fatal_lang_error('not_a_topic', false);
		
		// Always do the permission check!
		if (!allowedTo('rft_permission_boost'))
		  fatal_error(sprintf($txt['rft_cannot_boost']), false);
		
		// Make sure that the correct session was passed?
		checkSession('get');
		
		$rft_hide_topics = array($topic);
		
		if (empty($modSettings['rft_hide_topics']))
			updateSettings(array('rft_hide_topics' => serialize($rft_hide_topics)));
		else
		{
			$rft_hide_topics = array_merge($rft_topics, $rft_hide_topics);
			updateSettings(array('rft_hide_topics' => serialize($rft_hide_topics)));
		}
		
		//Dismiss if match with boosted topic
		if ($topic == $modSettings['rft_boost_1'])
			updateSettings(array('rft_boost_1' => false));
		if ($topic == $modSettings['rft_boost_2'])
			updateSettings(array('rft_boost_2' => false));

		// Log this boost action - always a moderator thing.
		logAction('hidden', array('topic' => $topic, 'board' => $board));
		
		// Take them back to the hidden topic.
		redirectexit('topic=' . $topic . '.' . $_REQUEST['start'] . (WIRELESS ? ';moderate' : ''));
	}
	
	if (isset($_REQUEST['area']) && ($_REQUEST['area'] == 'close'))
	{
		// Always do the permission check!
		if (!$context['user']['is_admin'])
			fatal_error(sprintf($txt['rft_admin_attempt']), true);		
		// Make sure that the correct session was passed?
		checkSession('get');
		
		updateSettings(array('rft_set_areas' => 'stop'));

		redirectexit($modSettings['rft_redirect']);	
	}
	
	// Add the elements above placement current action
	if (isset($_REQUEST['area']) && ($_REQUEST['area'] == 'aboveupdate'))
	{ 			
		// Always do the permission check!
		if (!$context['user']['is_admin'])
			fatal_error(sprintf($txt['rft_admin_attempt']), true);		
		
		// Make sure that the correct session was passed?
		checkSession('get');
		
		// Save the above area placements
		$rft_area1 = !empty($modSettings['rft_above_areas']) ? unserialize($modSettings['rft_above_areas']) : array();
		$rft_area2 = array_merge($rft_area1, $rft_current_action);
		$rft_area3 = array_filter($rft_area2); // no empty values please!!!
		$rft_area4 = array_unique($rft_area3); // to be sure
		natcasesort($rft_area4);

		updateSettings(array('rft_above_areas' => serialize($rft_area4)));
	
		redirectexit($modSettings['rft_redirect']);	
	}
	
	// Remove the elements above placement current action
	if (isset($_REQUEST['area']) && ($_REQUEST['area'] == 'aboveremove'))
	{
		// Always do the permission check!
		if (!$context['user']['is_admin'])
			fatal_error(sprintf($txt['rft_admin_attempt']), true);		
		
		// Make sure that the correct session was passed?
		checkSession('get');
	
		// Save the above area placements
		$rft_area1 = !empty($modSettings['rft_above_areas']) ? unserialize($modSettings['rft_above_areas']) : array();
		$rft_area2 = array_diff($rft_area1,$rft_current_action);
		$rft_area3 = array_filter($rft_area2); // no empty values please!!!
		$rft_area4 = array_unique($rft_area3); // to be sure
		natcasesort($rft_area4);
		
		updateSettings(array('rft_above_areas' => serialize($rft_area4)));		
		
		redirectexit($modSettings['rft_redirect']);	
	}
	
	// Add the elements below placement current action
	if (isset($_REQUEST['area']) && ($_REQUEST['area'] == 'belowupdate'))
	{		
		// Always do the permission check!
		if (!$context['user']['is_admin'])
			fatal_error(sprintf($txt['rft_admin_attempt']), true);		
		
		// Make sure that the correct session was passed?
		checkSession('get');	
	
		// Save the below area placements
		$rft_area1 = !empty($modSettings['rft_below_areas']) ? unserialize($modSettings['rft_below_areas']) : array();
		$rft_area2 = array_merge($rft_area1,$rft_current_action);
		$rft_area3 = array_filter($rft_area2); // no empty values please!!!
		$rft_area4 = array_unique($rft_area3); // to be sure
		natcasesort($rft_area4);
		
		updateSettings(array('rft_below_areas' => serialize($rft_area4)));
		
		redirectexit($modSettings['rft_redirect']);	
	}
	
	// Remove the elements below placement current action
	if (isset($_REQUEST['area']) && ($_REQUEST['area'] == 'belowremove'))
	{
		// Always do the permission check!
		if (!$context['user']['is_admin'])
			fatal_error(sprintf($txt['rft_admin_attempt']), true);		
		
		// Make sure that the correct session was passed?
		checkSession('get');
	
		// Save the below area placements
		$rft_area1 = !empty($modSettings['rft_below_areas']) ? unserialize($modSettings['rft_below_areas']) : array();
		$rft_area2 = array_diff($rft_area1,$rft_current_action);
		$rft_area3 = array_filter($rft_area2); // no empty values please!!!
		$rft_area4 = array_unique($rft_area3); // to be sure
		natcasesort($rft_area4);
		
		updateSettings(array('rft_below_areas' => serialize($rft_area4)));
		
		redirectexit($modSettings['rft_redirect']);	
	}
	
	fatal_error(sprintf($txt['rft_area_attempt']), true);
}

?>